package jalview.schemes;

public class ColourSchemeProperty
{
  public static final int CLUSTAL = 0;
  public static final int BLOSUM = 1;
  public static final int PID = 2;
  public static final int ZAPPO = 3;
  public static final int HYDROPHOBIC=4;
  public static final int HELIX=5;
  public static final int STRAND=6;
  public static final int TURN = 7;
  public static final int BURIED = 8;
  public static final int NUCLEOTIDE = 9;
  public static final int USER_DEFINED = 10;
  public static final int NONE = 11;

  public static int getColourIndexFromName(String name)
  {
    int ret=11;
    if(name.equals("Clustal"))
      ret = CLUSTAL;
    else if(name.equals("Blosum62"))
      ret = BLOSUM;
    else if(name.equals("% Identity"))
      ret = PID;
    else if(name.equals("Zappo"))
      ret = ZAPPO;
    else if(name.equals("Hydrophobic"))
      ret = HYDROPHOBIC;
    else if(name.equals("Helix Propensity"))
      ret = HELIX;
    else if(name.equals("Strand Propensity"))
      ret = STRAND;
    else if(name.equals("Turn Propensity"))
      ret = TURN;
    else if(name.equals("Buried Index"))
      ret = BURIED;
    else if(name.equals("Nucleotide"))
      ret = NUCLEOTIDE;
    else if(name.equals("User Defined"))
      ret =  USER_DEFINED;

    return ret;
  }

  public static String getColourName(int index)
  {
    String ret=null;
    switch(index)
    {
      case CLUSTAL: ret = "Clustal";    break;
      case BLOSUM:  ret = "Blosum62";   break;
      case PID:     ret = "% Identity"; break;
      case ZAPPO:   ret = "Zappo";      break;
      case HYDROPHOBIC: ret="Hydrophobic";break;
      case HELIX:   ret="Helix Propensity";break;
      case STRAND:  ret="Strand Propensity";break;
      case TURN:    ret="Turn Propensity";break;
      case BURIED:  ret="Buried Index";break;
      case NUCLEOTIDE:ret="Nucleotide"; break;
      case USER_DEFINED:ret="User Defined";break;
      default: ret = "None"; break;
    }
    return ret;
  }

  public static ColourSchemeI getColour(jalview.datamodel.AlignmentI al, String name)
  {
    return getColour(al, getColourIndexFromName(name));
  }

  public static ColourSchemeI getColour(jalview.datamodel.AlignmentI al, int index)
  {
    ColourSchemeI cs = null;
    switch(index)
    {
      case CLUSTAL: cs = new ClustalxColourScheme(al.getSequences(), al.getWidth()); break;
      case BLOSUM: cs = new Blosum62ColourScheme(); break;
      case PID: cs = new PIDColourScheme();  break;
      case ZAPPO: cs = new ZappoColourScheme(); break;
      case HYDROPHOBIC: cs = new HydrophobicColourScheme(); break;
      case HELIX: cs = new HelixColourScheme(); break;
      case STRAND: cs = new StrandColourScheme(); break;
      case TURN: cs = new TurnColourScheme(); break;
      case BURIED: cs = new BuriedColourScheme(); break;
      case NUCLEOTIDE: cs = new NucleotideColourScheme(); break;
      case USER_DEFINED:
        if(jalview.bin.Cache.getProperty("USER_DEFINED_COLOUR")!=null)
        {
          cs = jalview.gui.UserDefinedColours.loadDefaultColours(jalview.bin.Cache.getProperty("USER_DEFINED_COLOUR"));
        }
        break;

      default: break;
    }

    return cs;
  }
}
